@@ -1,9 +1,10 @@
 '''Core features include an init function for skeleton'''
 import re
 import logging
+from types import ModuleType
 from typing import Dict, Optional, Any
 import click
-from munch import Munch, DefaultFactoryMunch  # type: ignore
+from dotmap import DotMap  # type: ignore
 from click_help_colors.utils import _colorize  # type: ignore
 from click_skeleton.advanced_group import AdvancedGroup
 from click_skeleton.decorators import add_options
@@ -49,6 +50,7 @@ def skeleton(
     auto_envvar_prefix: Optional[str] = None,
     cls: Any = None,
     commands: Optional[Dict[str, Any]] = None,
+    groups_package: Optional[ModuleType] = None,
     **kwargs: Any,
 ) -> Any:
     '''Generates an skeleton group with version options included'''
@@ -59,7 +61,7 @@ def skeleton(
     sensible_context_settings = DEFAULT_CONTEXT_SETTINGS
     sensible_context_settings['auto_envvar_prefix'] = auto_envvar_prefix
 
-    obj = DefaultFactoryMunch(Munch)
+    obj = DotMap()
     obj.prog_name = name
     obj.version = version
     obj.context_settings = sensible_context_settings
@@ -71,6 +73,9 @@ def skeleton(
     commands = commands if commands is not None else {}
     commands['completion'] = completion_cli
     commands['version'] = version_cmd
+    if groups_package is not None and cls is AdvancedGroup:
+        kwargs['groups_package'] = groups_package
+
     return add_options(
         version_option(
             version=version,
