@@ -6,6 +6,7 @@ from html.parser import HTMLParser
 from typing import Any, Optional, Tuple, List
 import click
 import requests
+from requests.auth import HTTPBasicAuth
 import semver  # type: ignore
 
 
@@ -33,27 +34,34 @@ class MyParser(HTMLParser):
         if tag == 'a':
             self.output_list.append(dict(attrs).get('href'))
 
-    def error(self, message: str) -> None:
-        '''Print parsing error, implement parser abstract method'''
-        logger.error(message)
-
 
 class VersionCheckerThread(threading.Thread):
     '''Background thread to check version, to start at beginning of CLI'''
-    def __init__(self, prog_name: str, current_version: str, domain: str = DEFAULT_PYPI, autostart: bool = True, **kwargs: Any):
+    def __init__(
+        self,
+        prog_name: str,
+        current_version: str,
+        domain: str = DEFAULT_PYPI,
+        autostart: bool = True,
+        auth: Optional[HTTPBasicAuth] = None,
+        timeout: int = 15,
+        **kwargs: Any,
+    ):
         super().__init__(**kwargs)
         self.prog_name = prog_name
+        self.timeout = timeout
         self.new_version_warning: Optional[str] = None
         self.domain = domain
         self.current_version = current_version
         self.url = f'https://{domain}/simple/{prog_name}/'
+        self.auth = auth
         if autostart:
             self.start()
 
     def run(self) -> None:
         '''This threads auto-start by default and store a result you can read at end of program execution'''
         try:
-            resp = requests.get(self.url)
+            resp = requests.get(self.url, auth=self.auth, timeout=self.timeout)
             if not resp.ok:
                 logger.info(f'{self.prog_name} : unable to fetch {self.url} : {resp.text}')  # pylint: disable=logging-fstring-interpolation
                 return
@@ -85,7 +93,7 @@ class VersionCheckerThread(threading.Thread):
 {self.prog_name} : new version {last_version} available (current version: {self.current_version})
 upgrade command :
     pip3 install -U {pip_extra_index_url}{self.prog_name}
-    pipx upgrade {pipx_extra_index_url}{self.prog_name}''',
+OR  pipx upgrade {pipx_extra_index_url}{self.prog_name} (preferred)''',
                     fg='bright_blue',
                 )
         except Exception as error:  # pylint: disable=broad-except
@@ -95,12 +103,17 @@ upgrade command :
         '''Join thread and print result on stderr'''
         try:
             if not self.is_alive():
-                logger.debug('Version checker thread may have exited')
+                logger.debug('Version checker thread may have already exited')
+                self.print_new_version()
                 return
             self.join()
-            if self.new_version_warning:
-                click.echo(self.new_version_warning, err=True)
-            else:
-                logger.info(f'{self.prog_name} : no new version available')  # pylint: disable=logging-fstring-interpolation
+            self.print_new_version()
         except Exception as error:  # pylint: disable=broad-except
             logger.exception(error)
+
+    def print_new_version(self):
+        '''Print new version if information available'''
+        if self.new_version_warning:
+            click.echo(self.new_version_warning, err=True)
+        else:
+            logger.info(f'{self.prog_name} : no new version available')  # pylint: disable=logging-fstring-interpolation
